@@ -109,6 +109,7 @@ class Interpreter:
         self.error      = []
         self.expr       = None
         self.retval     = None
+        self._calldepth = 0
         self.func       = None
         self.fname      = '<stdin>'
         self.lineno     = 0
@@ -431,9 +432,10 @@ class Interpreter:
 
     def on_return(self, node): # ('value',)
         "return statement: look for None, return special sentinal"
+        if self._calldepth == 0:
+            raise SyntaxError('cannot return at top level')
         ret = self.run(node.value)
-        if ret is None: ret = ReturnedNone
-        self.retval = ret
+        self.retval = ret if ret is not None else ReturnedNone
         return
 
     def on_repr(self, node):
@@ -836,13 +838,20 @@ class Interpreter:
         if kwargs is not None:
             keywords.update(self.run(kwargs))
 
+        if isinstance(func, Procedure):
+            self._calldepth += 1
         try:
-            return func(*args, **keywords)
+            out = func(*args, **keywords)
         except Exception as ex:
+            out = None
             func_name = getattr(func, '__name__', str(func))
             self.raise_exception(
                 node, msg="Error running function call '%s' with args %s and "
                 "kwargs %s: %s" % (func_name, args, keywords, ex))
+        finally:
+            if isinstance(func, Procedure):
+                self._calldepth -= 1
+        return out
 
     def on_functiondef(self, node):
         "define procedures"
