@@ -334,6 +334,7 @@ class Procedure(object):
         stable.set_frame((lgroup, self.modgroup))
         retval = None
         self._larch.retval = None
+        self._larch._calldepth += 1
         self._larch.debug = True
         for node in self.body:
             self._larch.run(node, fname=self.__file__, func=self,
@@ -345,6 +346,7 @@ class Procedure(object):
                 if retval is ReturnedNone: retval = None
                 break
         stable.restore_frame()
+        self._larch._calldepth -= 1
         self._larch.debug = False
         self._larch.retval = None
         del lgroup
@@ -574,11 +576,12 @@ def Make_CallArgs(skipped_args):
                 if k in call_args:
                     call_args.pop(k)
 
-            details_name = '%s_details' % fcn.__name__
-            if not hasattr(groupx, details_name):
-                setattr(groupx, details_name, Group())
-            setattr(getattr(groupx, details_name),
-                    'call_args', call_args)
+            if groupx is not None:
+                details_name = '%s_details' % fcn.__name__
+                if not hasattr(groupx, details_name):
+                    setattr(groupx, details_name, Group())
+                setattr(getattr(groupx, details_name),
+                        'call_args', call_args)
             return result
         wrapper.__doc__ = fcn.__doc__
         wrapper.__name__ = fcn.__name__
