@@ -22,8 +22,9 @@ from xraydb.chemparser import chemparse
 import larch
 from larch import Group
 from larch.xafs import feff8l, feff6l
+from larch.xrd.cif2feff import cif_sites
 from larch.utils.paths import unixpath
-from larch.utils.strutils import fix_filename, unique_name
+from larch.utils.strutils import fix_filename, unique_name, strict_ascii
 from larch.site_config import user_larchdir
 
 from larch.wxlib import (LarchFrame, FloatSpin, EditableListBox,
@@ -122,7 +123,9 @@ class CIFFrame(wx.Frame):
 
         minlab = SimpleText(panel, ' Mineral Name: ')
         minhint= SimpleText(panel, ' example: hem* ')
-        wids['mineral'] = wx.TextCtrl(panel, value='',   size=(250, -1))
+        wids['mineral'] = wx.TextCtrl(panel, value='',   size=(250, -1),
+                                      style=wx.TE_PROCESS_ENTER)
+        wids['mineral'].Bind(wx.EVT_TEXT_ENTER, self.onSearch)
 
         authlab = SimpleText(panel, ' Author Name: ')
         wids['author'] = wx.TextCtrl(panel, value='',   size=(250, -1))
@@ -329,12 +332,12 @@ class CIFFrame(wx.Frame):
         if len(contains_elements) < 1:
             contains_elements = None
         else:
-            contains_elements = [a.strip() for a in contains_elements.split(',')]
+            contains_elements = [a.strip().title() for a in contains_elements.split(',')]
         excludes_elements = self.wids['excludes_elements'].GetValue().strip()
         if len(excludes_elements) < 1:
             excludes_elements = None
         else:
-            excludes_elements = [a.strip() for a in excludes_elements.split(',')]
+            excludes_elements = [a.strip().title() for a in excludes_elements.split(',')]
         strict_contains = self.wids['strict_contains'].IsChecked()
         full_occupancy = self.wids['full_occupancy'].IsChecked()
         all_cifs = find_cifs(mineral_name=mineral_name,
@@ -389,7 +392,7 @@ class CIFFrame(wx.Frame):
         self.wids['central_atom'].Select(0)
 
         el0 = list(elems.keys())[0]
-        sites = [a for a in cif.atoms_sites if a.startswith(el0)]
+        sites = cif_sites(cif.ciftext, absorber=el0)
         sites = ['%d' % (i+1) for i in range(len(sites))]
         self.wids['site'].Clear()
         self.wids['site'].AppendItems(sites)
@@ -399,8 +402,10 @@ class CIFFrame(wx.Frame):
 
 
     def onCentralAtom(self, event=None):
-        elem = event.GetString()
-        sites = [a for a in self.current_cif.atoms_sites if a.startswith(elem)]
+        cif  = self.current_cif
+        if cif is None:
+            return
+        sites = cif_sites(cif.ciftext, absorber=event.GetString())
         sites = ['%d' % (i+1) for i in range(len(sites))]
         self.wids['site'].Clear()
         self.wids['site'].AppendItems(sites)
@@ -463,7 +468,7 @@ class CIFFrame(wx.Frame):
 
         fname = unixpath(os.path.join(folder, 'feff.inp'))
         with open(fname, 'w') as fh:
-            fh.write(fefftext)
+            fh.write(strict_ascii(fefftext))
 
         wx.CallAfter(self.run_feff, folder, version8=version8)
         # feffexe, folder=dirname, message_writer=self.feff_output)
@@ -537,7 +542,6 @@ class CIFFrame(wx.Frame):
                 fh.write(cc.ciftext)
             self.write_message("Wrote CIF file %s" % path, 0)
 
-
     def onImportCIF(self, event=None):
         wildcard = 'CIF files (*.cif)|*.cif|All files (*.*)|*.*'
         path = FileOpen(self, message='Open CIF File',
@@ -671,4 +675,3 @@ def cif_viewer(**kws):
 
 if __name__ == '__main__':
     CIFViewer().MainLoop()
-
