@@ -246,10 +246,11 @@ class EditColumnFrame(wx.Frame) :
             cind = SimpleText(panel, label='  %i ' % (i+1))
             cold = SimpleText(panel, label=' %s ' % name)
             cret = SimpleText(panel, label=fix_varname(name), size=(150, -1))
-            cnew = wx.TextCtrl(panel,  value=name, size=(150, -1))
+            cnew = wx.TextCtrl(panel, value=name, size=(150, -1),
+                               style=wx.TE_PROCESS_ENTER)
 
+            cnew.Bind(wx.EVT_TEXT_ENTER, partial(self.update, index=i))
             cnew.Bind(wx.EVT_KILL_FOCUS, partial(self.update, index=i))
-            cnew.Bind(wx.EVT_CHAR, partial(self.update_char, index=i))
 
             arr = group.data[i,:]
             info_str = " [ %8g : %8g ] " % (arr.min(), arr.max())
@@ -303,7 +304,7 @@ class EditColumnFrame(wx.Frame) :
     def update_char(self, evt=None, index=-1):
         if evt.GetKeyCode() == wx.WXK_RETURN:
             self.update(evt=evt, index=index)
-        evt.Skip()
+        # evt.Skip()
 
     def onOK(self, evt=None):
         group = self.group
@@ -339,13 +340,15 @@ class ColumnDataFileFrame(wx.Frame) :
 
         if self.workgroup.datatype is None:
             self.workgroup.datatype = 'raw'
+            en_units = 'not energy'
             for arrlab in arr_labels[:4]:
                 if 'ener' in arrlab.lower():
+                    en_units = 'eV'
                     self.workgroup.datatype = 'xas'
 
         self.read_ok_cb = read_ok_cb
         self.array_sel = dict(xarr=None, yarr1=None, yarr2=None, yop='/',
-                              ypop='', monod=3.1355316, en_units='eV',
+                              ypop='', monod=3.1355316, en_units=en_units,
                               yerror='constant', yerr_val=1, yerr_arr=None)
         if last_array_sel is not None:
             self.array_sel.update(last_array_sel)
@@ -809,12 +812,13 @@ class ColumnDataFileFrame(wx.Frame) :
         if xname.startswith('_index') or ix >= ncol:
             workgroup.xdat = 1.0*np.arange(npts)
         else:
-            workgroup.xdat = 1.0*rdata[ix, :]
-        eguess =  guess_energy_units(workgroup.xdat)
-        if eguess.startswith('eV'):
-            self.en_units.SetStringSelection('eV')
-        elif eguess.startswith('keV'):
-            self.en_units.SetStringSelection('keV')
+            workgroup.xdat = 1.0*rdata[ix, :] 
+        if self.datatype.GetStringSelection().strip().lower() != 'raw':           
+            eguess =  guess_energy_units(workgroup.xdat)
+            if eguess.startswith('eV'):
+                self.en_units.SetStringSelection('eV')
+            elif eguess.startswith('keV'):
+                self.en_units.SetStringSelection('keV')
 
     def onUpdate(self, value=None, evt=None):
         """column selections changed calc xdat and ydat"""
@@ -840,6 +844,10 @@ class ColumnDataFileFrame(wx.Frame) :
             workgroup.xdat = 1.0*rdata[ix, :]
             exprs['xdat'] = '%%s.data[%i, : ]' % ix
 
+        workgroup.datatype = self.datatype.GetStringSelection().strip().lower()
+        if workgroup.datatype == 'raw':
+            self.en_units.SetStringSelection('not energy')
+            
         xlabel = xname
         en_units = self.en_units.GetStringSelection()
         if en_units.startswith('deg'):
@@ -850,7 +858,6 @@ class ColumnDataFileFrame(wx.Frame) :
             workgroup.xdat *= 1000.0
             xlabel = xname + ' (eV)'
 
-        workgroup.datatype = self.datatype.GetStringSelection().strip().lower()
 
         def pre_op(opwid, arr):
             opstr = opwid.GetStringSelection().strip()
