@@ -429,7 +429,7 @@ class EXAFSPanel(TaskPanel):
         if as_copy:
             conf = copy.deepcopy(conf)
         if dgroup is not None:
-            setattr(dgroup, self.configname, conf)            
+            setattr(dgroup, self.configname, conf)
         return conf
 
 
@@ -491,20 +491,34 @@ class EXAFSPanel(TaskPanel):
             return
         self.last_process_time = time.time()
         self.skip_process = True
-        self.process(dgroup=self.dgroup)
+        self.process(dgroup=self.dgroup, read_form=True)
         self.skip_process = False
         plotter = self.onPlotSel if self.last_plot=='selected' else self.onPlotOne
         plotter()
 
-    def process(self, dgroup=None, **kws):
+    def process(self, dgroup=None, read_form=True, **kws):
+        conf = {}
         if dgroup is not None:
             self.dgroup = dgroup
+            conf = getattr(dgroup, self.configname, None)
+            if conf is None:
+                conf = self.get_config(dgroup=dgroup)
+
+        if read_form:
+            conf.update(self.read_form())
 
-        conf = self.read_form()
         conf.update(kws)
-        if not 'fft_kwindow' in conf:
+        if dgroup is None or 'fft_kwindow' not in conf:
             return
 
+        if 'group' not in conf:
+            conf['group'] = dgroup.groupname
+
+        try:
+            txt = autobk_cmd.format(**conf)
+        except:
+            conf.update(self.read_form())
+
         bkgpars = []
         # print(" EXAFS Process #1 e0= ", conf.get('e0', -10.))
         for attr in ('e0', 'rbkg', 'bkg_kmin', 'bkg_kmax',
@@ -514,8 +528,6 @@ class EXAFSPanel(TaskPanel):
                 val = -1.0
             bkgpars.append("%.3f" % val)
         bkgpars = ':'.join(bkgpars)
-        # print(" EXAFS Process #2 : ", bkgpars, self.dgroup.groupname,
-        #       bkgpars == self.last_process_bkg.get(self.dgroup.groupname, ''))
 
         if bkgpars != self.last_process_bkg.get(self.dgroup.groupname, ''):
             self.larch_eval(autobk_cmd.format(**conf))
@@ -527,9 +539,6 @@ class EXAFSPanel(TaskPanel):
                      'fft_rmin', 'fft_rmax', 'fft_dr'):
             fftpars.append("%.3f" % conf.get(attr, 0.0))
         fftpars = ':'.join(fftpars)
-
-        # print(" EXAFS Process #3 : ", fftpars, self.dgroup.groupname,
-        #       fftpars == self.last_process_fft.get(self.dgroup.groupname, ''))
         if fftpars != self.last_process_fft.get(self.dgroup.groupname, ''):
             self.larch_eval(xftf_cmd.format(**conf))
             self.larch_eval(xftr_cmd.format(**conf))
@@ -585,7 +594,8 @@ class EXAFSPanel(TaskPanel):
                 conf['group'] = dgroup.groupname
                 conf['label'] = dgroup.filename
                 conf['offset'] = offset * i
-                self.process(dgroup=dgroup)
+                if not hasattr(dgroup, 'chir_mag'):
+                    self.process(dgroup=dgroup, read_form=False)
 
                 extra = """, offset={offset:.3f}, win=1, delay_draw=True,
     label='{label:s}', new={new:s})"""
