@@ -14,15 +14,16 @@ from lmfit import Parameters, Parameter, Minimizer, fit_report
 from lmfit.printfuncs import gformat as gformat
 
 from larch import Group, isNamedClass
-
+from larch.utils.strutils import fix_varname
 from ..math import index_of, realimag, complex_phase
-from ..fitting import (correlated_values, eval_stderr,
+from ..fitting import (correlated_values, eval_stderr, ParameterGroup,
                        group2params, params2group, isParameter)
 
 from .xafsutils import set_xafsGroup
 from .xafsft import xftf_fast, xftr_fast, ftwindow
 from .sigma2_models import sigma2_correldebye, sigma2_debye
-from .feffdat import PATHPAR_FMT, FeffPathGroup, ff2chi
+from .feffdat import FeffPathGroup, ff2chi
+
 
 class TransformGroup(Group):
     """A Group of transform parameters.
@@ -224,16 +225,26 @@ class TransformGroup(Group):
         return (out*self._cauchymask)[self._cauchyslice]
 
 class FeffitDataSet(Group):
-    def __init__(self, data=None, pathlist=None, transform=None,
-                 epsilon_k=None, _larch=None, **kws):
+    def __init__(self, data=None, paths=None, transform=None,
+                 epsilon_k=None, _larch=None, pathlist=None, **kws):
         self._larch = _larch
         Group.__init__(self, **kws)
 
-        self.pathlist = pathlist
+        if paths is None and pathlist is not None:  # legacy
+            paths = pathlist
+
+        if isinstance(paths, dict):
+            self.paths = {key: copy(path) for key, path in paths.items()}
+        elif isinstance(paths, (list, tuple)):
+            self.paths = {path.label: copy(path) for path in paths}
+        else:
+            self.paths = {}
 
         self.data = data
         if transform is None:
             transform = TransformGroup()
+        else:
+            trasform = copy(transform)
         self.transform = transform
         if epsilon_k is not None:
             self.data.epsilon_k = epsilon_k
@@ -248,14 +259,14 @@ class FeffitDataSet(Group):
 
     def __copy__(self):
         return FeffitDataSet(data=copy(self.data),
-                             pathlist=self.pathlist[:],
-                             transform=copy(self.transform),
+                             paths=self.paths,
+                             transform=self.transform,
                              _larch=self._larch)
 
     def __deepcopy__(self, memo):
         return FeffitDataSet(data=deepcopy(self.data),
-                             pathlist=self.pathlist[:],
-                             transform=deepcopy(self.transform),
+                             paths=self.paths,
+                             transform=self.transform,
                              _larch=self._larch)
 
     def prepare_fit(self, params):
@@ -287,9 +298,9 @@ class FeffitDataSet(Group):
                 eps_k = np.sqrt(_dchi**2 + self.epsilon_k**2)
                 self.set_epsilon_k(eps_k)
 
-        # for each path in the pathlist, setup the Path Parameters
+        # for each path in the list of paths, setup the Path Parameters
         # to use the current Parameters namespace
-        for path in self.pathlist:
+        for label, path in self.paths.items():
             path.create_path_params(params=params)
             if path.spline_coefs is None:
                 path.create_spline_coefs()
@@ -367,14 +378,14 @@ class FeffitDataSet(Group):
     def _residual(self, paramgroup, data_only=False, **kws):
         """return the residual for this data set
         residual = self.transform.apply(data_chi - model_chi)
-        where model_chi is the result of ff2chi(pathlist)
+        where model_chi is the result of ff2chi(paths)
         """
         if not isNamedClass(self.transform, TransformGroup):
             return
         if not self.__prepared:
             self.prepare_fit()
 
-        ff2chi(self.pathlist, paramgroup=paramgroup, k=self.model.k,
+        ff2chi(self.paths, paramgroup=paramgroup, k=self.model.k,
                 _larch=self._larch, group=self.model)
 
         eps_k = self.epsilon_k
@@ -436,18 +447,20 @@ class FeffitDataSet(Group):
         xft(self.__chi,   group=self.data,  rmax_out=rmax_out)
         xft(self.model.chi, group=self.model, rmax_out=rmax_out)
         if path_outputs:
-            for p in self.pathlist:
+            for p in self.paths.values():
                 xft(p.chi, group=p, rmax_out=rmax_out)
 
-def feffit_dataset(data=None, pathlist=None, transform=None,
-                   epsilon_k=None, _larch=None):
+def feffit_dataset(data=None, paths=None, transform=None,
+                   epsilon_k=None, pathlist=None, _larch=None):
     """create a Feffit Dataset group.
 
      Parameters:
      ------------
       data:      group containing experimental EXAFS (needs arrays 'k' and 'chi').
-      pathlist:  list of FeffPath groups, as created from feffpath()
+      paths:     dict of {label: FeffPathGroup}, using FeffPathGroup created by feffpath()
       transform: Feffit Transform group.
+      pathlist:  list of FeffPathGroup [deprecated - use 'paths']
+
       epsilon_k: Uncertainty in data (either single value or array of
                  same length as data.k)
 
@@ -457,8 +470,8 @@ def feffit_dataset(data=None, pathlist=None, transform=None,
 
 
     """
-    return FeffitDataSet(data=data, pathlist=pathlist,
-                         transform=transform, _larch=_larch)
+    return FeffitDataSet(data=data, paths=paths, transform=transform,
+                         pathlist=pathlist, _larch=_larch)
 
 def feffit_transform(_larch=None, **kws):
     """create a feffit transform group
@@ -517,16 +530,17 @@ def feffit(paramgroup, datasets, rmax_out=10, path_outputs=True, _larch=None, **
         chir_im      imaginary part of chi(R).
     """
 
+    work_paramgroup = deepcopy(paramgroup)
+    params = group2params(work_paramgroup)
 
-    def _resid(params, datasets=None, paramgroup=None, **kwargs):
+    def _resid(params, datasets=None, pargroup=None, **kwargs):
         """ this is the residual function"""
-        params2group(params, paramgroup)
-        return concatenate([d._residual(paramgroup) for d in datasets])
+        params2group(params, pargroup)
+        return concatenate([d._residual(pargroup) for d in datasets])
 
     if isNamedClass(datasets, FeffitDataSet):
         datasets = [datasets]
 
-    params = group2params(paramgroup)
     for ds in datasets:
         if not isNamedClass(ds, FeffitDataSet):
             print( "feffit needs a list of FeffitDataSets")
@@ -534,14 +548,13 @@ def feffit(paramgroup, datasets, rmax_out=10, path_outputs=True, _larch=None, **
         ds.prepare_fit(params=params)
 
     fit = Minimizer(_resid, params,
-                    fcn_kws=dict(datasets=datasets,
-                                 paramgroup=paramgroup),
+                    fcn_kws=dict(datasets=datasets, pargroup=work_paramgroup),
                     scale_covar=True, **kws)
 
     result = fit.leastsq()
+    params2group(result.params, work_paramgroup)
 
-    params2group(result.params, paramgroup)
-    dat = concatenate([d._residual(paramgroup, data_only=True) for d in datasets])
+    dat = concatenate([d._residual(work_paramgroup, data_only=True) for d in datasets])
 
     n_idp = 0
     for ds in datasets:
@@ -550,7 +563,7 @@ def feffit(paramgroup, datasets, rmax_out=10, path_outputs=True, _larch=None, **
     # here we rescale chi-square and reduced chi-square to n_idp
     npts =  len(result.residual)
     chi_square  = result.chisqr * n_idp*1.0 / npts
-    chi_reduced = chi_square/(n_idp*1.0 - result.nvarys)
+    chi2_reduced = chi_square/(n_idp*1.0 - result.nvarys)
     rfactor = (result.residual**2).sum() / (dat**2).sum()
     # calculate 'aic', 'bic' rescaled to n_idp
     # note that neg2_loglikel is -2*log(likelihood)
@@ -569,9 +582,9 @@ def feffit(paramgroup, datasets, rmax_out=10, path_outputs=True, _larch=None, **
     if covar is not None:
         err_scale = (result.nfree / (n_idp - result.nvarys))
         for name in result.var_names:
-            p = result.params[name]
-            if isParameter(p) and p.vary:
-                p.stderr *= sqrt(err_scale)
+            par = result.params[name]
+            if isParameter(par) and par.vary:
+                par.stderr *= sqrt(err_scale)
 
         # next, propagate uncertainties to constraints and path parameters.
         result.covar *= err_scale
@@ -589,15 +602,14 @@ def feffit(paramgroup, datasets, rmax_out=10, path_outputs=True, _larch=None, **
         for nam, obj in result.params.items():
             eval_stderr(obj, uvars,  result.var_names, result.params)
 
-        # 3. evaluate path params, save stderr
+        # 3. evaluate path_ params, save stderr
         for ds in datasets:
-            for p in ds.pathlist:
-                p.store_feffdat()
+            for label, path in ds.paths.items():
+                path.store_feffdat()
                 for pname in ('degen', 's02', 'e0', 'ei',
                               'deltar', 'sigma2', 'third', 'fourth'):
-                    obj = p.params[PATHPAR_FMT % (pname, p.label)]
+                    obj = path.params[path.pathpar_name(pname)]
                     eval_stderr(obj, uvars,  result.var_names, result.params)
-
         # restore saved parameters again
         for vname in result.var_names:
             # setattr(params, vname, vsave[vname])
@@ -608,15 +620,16 @@ def feffit(paramgroup, datasets, rmax_out=10, path_outputs=True, _larch=None, **
             _larch.error = []
 
     # reset the parameters group with the newly updated uncertainties
-    params2group(result.params, paramgroup)
+    params2group(result.params, work_paramgroup)
 
     # here we create outputs arrays for chi(k), chi(r):
     for ds in datasets:
         ds.save_ffts(rmax_out=rmax_out, path_outputs=path_outputs)
 
     out = Group(name='feffit results', datasets=datasets,
+                paramgroup=work_paramgroup,
                 fitter=fit, fit_details=result, chi_square=chi_square,
-                n_independent=n_idp, chi_reduced=chi_reduced,
+                n_independent=n_idp, chi2_reduced=chi2_reduced,
                 rfactor=rfactor, aic=aic, bic=bic, covar=covar)
 
     for attr in ('params', 'nvarys', 'nfree', 'ndata', 'var_names', 'nfev',
@@ -650,9 +663,9 @@ def feffit_report(result, min_correl=0.1, with_paths=True, _larch=None):
         print( 'must pass output of feffit()!')
         return
 
-    path_labels = []
+    path_hashkeys = []
     for ds in datasets:
-        path_labels.extend([p.label for p in ds.pathlist])
+        path_hashkeys.extend([p.hashkey for p in ds.paths.values()])
     topline = '=================== FEFFIT RESULTS ===================='
     header = '[[%s]]'
     varformat  = '   %12s = %s +/-%s   (init= %s)'
@@ -664,7 +677,7 @@ def feffit_report(result, min_correl=0.1, with_paths=True, _larch=None):
                                                    result.ndata))
     out.append('   n_independent      =  %.3f'  % (result.n_independent))
     out.append('   chi_square         = %s'  % gformat(result.chi_square))
-    out.append('   reduced chi_square = %s'  % gformat(result.chi_reduced))
+    out.append('   reduced chi_square = %s'  % gformat(result.chi2_reduced))
     out.append('   r-factor           = %s'  % gformat(result.rfactor))
     out.append('   Akaike info crit   = %s'  % gformat(result.aic))
     out.append('   Bayesian info crit = %s'  % gformat(result.bic))
@@ -704,7 +717,7 @@ def feffit_report(result, min_correl=0.1, with_paths=True, _larch=None):
         if tr.dk2 is not None:
             kwin = "%s, %.3f" % (kwin, tr.dk2)
         out.append(kwin)
-        pathfiles = [p.filename for p in ds.pathlist]
+        pathfiles = [p.filename for p in ds.paths.values()]
         out.append('   paths used in fit  = %s' % (repr(pathfiles)))
         out.append('   k-weight           = %s' % kweigh)
         out.append('   epsilon_k          = %s'  % eps_k)
@@ -714,7 +727,7 @@ def feffit_report(result, min_correl=0.1, with_paths=True, _larch=None):
     out.append(' ')
     out.append(header % 'Variables')
     for name, par in params.items():
-        if any([name.endswith('__%s' % p_lab) for p_lab in path_labels]):
+        if any([name.endswith('_%s' % phash) for phash in path_hashkeys]):
             continue
         if len(name) < 14:
             name = (name + ' '*14)[:14]
@@ -766,7 +779,7 @@ def feffit_report(result, min_correl=0.1, with_paths=True, _larch=None):
         for ids, ds in enumerate(datasets):
             if len(datasets) > 1:
                 out.append(' dataset %i:' % (ids+1))
-            for p in ds.pathlist:
-                out.append('%s\n' % p.report())
+            for label, path in ds.paths.items():
+                out.append('%s\n' % path.report())
     out.append('='*len(topline))
     return '\n'.join(out)
